@@ -41,7 +41,6 @@ describe 'glance::api' do
       :taskflow_engine_mode           => '<SERVICE DEFAULT>',
       :taskflow_max_workers           => '<SERVICE DEFAULT>',
       :conversion_format              => '<SERVICE DEFAULT>',
-      :enable_v1_api                  => false,
       :enable_v2_api                  => '<SERVICE DEFAULT>',
       :sync_db                        => true,
       :limit_param_default            => '<SERVICE DEFAULT>',
@@ -136,7 +135,6 @@ describe 'glance::api' do
             'cache_prefetcher_interval',
             'node_staging_uri',
             'image_member_quota',
-            'enable_v1_api',
             'enable_v2_api',
             'limit_param_default',
             'api_limit_max',
